==> finmath-lib-3.3.1-sources.jar: net/finmath/montecarlo/RandomVariableFactory.java <==
/*
 * (c) Copyright Christian P. Fries, Germany. Contact: email@christian-fries.de.
 *
 * Created on 09.02.2004
 */
package net.finmath.montecarlo;

import net.finmath.stochastic.RandomVariableInterface;

/**
 * A factory (helper class) to create random variables.
 *
 * By changing the factory implementation used, you can (more or less globally)
 * change which implementation of random variable is used.
 *
 * @author Christian Fries
 */
public class RandomVariableFactory extends AbstractRandomVariableFactory {

	private static final long serialVersionUID = 9124600813005863273L;

	final boolean isUseDoublePrecisionFloatingPointImplementation;

	public RandomVariableFactory() {
		super();
		this.isUseDoublePrecisionFloatingPointImplementation = true;
	}

	public RandomVariableFactory(boolean isUseDoublePrecisionFloatingPointImplementation) {
		super();
		this.isUseDoublePrecisionFloatingPointImplementation = isUseDoublePrecisionFloatingPointImplementation;
	}

	@Override
	public RandomVariableInterface createRandomVariable(double time, double value) {
		if(isUseDoublePrecisionFloatingPointImplementation) {
			return new RandomVariable(time, value);
		} else {
			return new RandomVariableLowMemory(time, value);
		}
	}

	@Override
	public RandomVariableInterface createRandomVariable(double time, double[] values) {
		if(isUseDoublePrecisionFloatingPointImplementation) {
			return new RandomVariable(time, values);
		} else {
			return new RandomVariableLowMemory(time, values);
		}
	}
}

==> finmath-lib-4.0.7-sources.jar: net/finmath/montecarlo/RandomVariableFactory.java <==
/*
 * (c) Copyright Christian P. Fries, Germany. Contact: email@christian-fries.de.
 *
 * Created on 09.02.2004
 */
package net.finmath.montecarlo;

import net.finmath.stochastic.RandomVariable;
import net.finmath.stochastic.Scalar;

/**
 * A factory (helper class) to create random variables.
 *
 * By changing the factory implementation used, you can (more or less globally)
 * change which implementation of random variable is used.
 *
 * @author Christian Fries
 * @version 1.0
 */
public class RandomVariableFactory extends AbstractRandomVariableFactory {

	private static final long serialVersionUID = 9124600813005863273L;

	final boolean isUseDoublePrecisionFloatingPointImplementation;

	public RandomVariableFactory() {
		super();
		this.isUseDoublePrecisionFloatingPointImplementation = true;
	}

	public RandomVariableFactory(boolean isUseDoublePrecisionFloatingPointImplementation) {
		super();
		this.isUseDoublePrecisionFloatingPointImplementation = isUseDoublePrecisionFloatingPointImplementation;
	}

	@Override
	public RandomVariable createRandomVariable(double value) {
		return new Scalar(value);
	}

	@Override
	public RandomVariable createRandomVariable(double time, double value) {
		return new Scalar(value);
		/*
		if(isUseDoublePrecisionFloatingPointImplementation) {
			return new RandomVariableFromDoubleArray(time, value);
		} else {
			return new RandomVariableFromFloatArray(time, value);
		}
		 */
	}

	@Override
	public RandomVariable createRandomVariable(double time, double[] values) {
		if(isUseDoublePrecisionFloatingPointImplementation) {
			return new RandomVariableFromDoubleArray(time, values);
		} else {
			return new RandomVariableFromFloatArray(time, values);
		}
	}
}
